
package simulation.consumers.web;

import javax.ws.rs.DefaultValue;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.MediaType;

import org.apache.log4j.Logger;

import simulation.common.globals.HistoryLogger;
import simulation.common.globals.HistoryLoggerTimedEntries;
import simulation.common.globals.SimulationState;

@Path("/controller")
public class SimulatorService {
	private final static Logger logger = Logger.getLogger(SimulatorService.class);
	
	@GET @Path("/run")
    @Produces(MediaType.APPLICATION_JSON)
	public BasicResult run() {
    	try{
    		MasonModelWebSController controller = MasonModelWebSController.getInstance();
    		if (controller.getState() != SimulationState.RUNNING){
    			controller.run();
    			if (controller.getState() == SimulationState.RUNNING){
    				return new BasicResult(true);
    			}
    		}
    		return new BasicResult(false);
		 }
		 catch(Exception e){
			 logger.error("Problems!!! Exception: " + e.getMessage());
			 return new BasicResult(false);
	     }
	}
    
    @GET @Path("/stop")
    @Produces(MediaType.APPLICATION_JSON)
    public BasicResult cancel() {
    	try{
    		MasonModelWebSController controller = MasonModelWebSController.getInstance();
    		if (controller.getState() == SimulationState.RUNNING){
    			controller.cancel();
    			if (controller.getState() == SimulationState.CANCELED){
    				return new BasicResult(true);
    			}
    		}
    		return new BasicResult(false);
    	}
    	catch(Exception e){
    		logger.error("Problems!!! Exception: " + e.getMessage());
    		return new BasicResult(false);
    	}
    }
    
    @GET @Path("/state")
    @Produces(MediaType.APPLICATION_JSON)
    public SimulStateData state() {
    	try{
    		MasonModelWebSController controller = MasonModelWebSController.getInstance();
    		SimulStateData state = new SimulStateData(controller.getState().getValue(), controller.getSimulTime().toString());
    		return state;
    	}
    	catch(Exception e){
    		logger.error("Problems!!! Exception: " + e.getMessage());
    		return new SimulStateData();
    	}
    }
    
    @GET @Path("/post")
    @Produces(MediaType.APPLICATION_JSON)
    public BasicResult post(
    		@DefaultValue("11") @QueryParam("moment") double moment,
    		@DefaultValue("0") @QueryParam("guidedAgentProportion") double guidedAgentProportion
    		) {
    	try{
    		System.out.println(moment);
    		System.out.println(guidedAgentProportion);
    		MasonModelWebSController controller = MasonModelWebSController.getInstance();
    		controller.setSimulationParameters(moment, guidedAgentProportion);
    		return new BasicResult(true);
    	}
    	catch(Exception e){
    		logger.error("Problems!!! Exception: " + e.getMessage());
    		return new BasicResult(false);
    	}
    }
    
    @GET @Path("/getslots")
    @Produces(MediaType.APPLICATION_JSON)
    public SlotListDetails<SlotClientData> getSlots() {
    	try{
    		MasonModelWebSController controller = MasonModelWebSController.getInstance();
    		SlotListDetails <SlotClientData> slcd = controller.getMapData();
    		return slcd;
    	}
    	catch(Exception e){
    		logger.error("Problems!!! Exception: " + e.getMessage());
    		return new SlotListDetails<SlotClientData>();
    	}
    }
    
    @GET @Path("/getslotsupdate")
    @Produces(MediaType.APPLICATION_JSON)
    public SlotListDetails<SlotClientState> getSlotsUpdate(@DefaultValue("0") @QueryParam("time") long requestedTime) {
    	try{
    		MasonModelWebSController controller = MasonModelWebSController.getInstance();
    		SlotListDetails<SlotClientState> slcd = controller.getMapUpdates(requestedTime);
    		return slcd;
    	}
    	catch(Exception e){
    		logger.error("Problems!!! Exception: " + e.getMessage());
    		return new SlotListDetails<SlotClientState>();
    	}
    }
    
    @GET @Path("getlogs")
    @Produces(MediaType.APPLICATION_JSON)
	public HistoryLoggerTimedEntries getLogs(@DefaultValue("0") @QueryParam("time") long requestedTime) {
    	try{
    		HistoryLogger historyLogger = HistoryLogger.getInstance();
    		return historyLogger.getEntries(requestedTime);
		 }
		 catch(Exception e){
			 logger.error("Problems!!! Exception: " + e.getMessage());
			 return new HistoryLoggerTimedEntries(null, 0);
	     }
	}
    
    @GET @Path("getco2")
    @Produces(MediaType.APPLICATION_JSON)
	public ActivityIndicators getCO2() {
    	try{
    		MasonModelWebSController controller = MasonModelWebSController.getInstance();
    		ActivityIndicators ind = controller.getCO2Indicators();
    		ActivityIndicators indicators = new ActivityIndicators(
    				ind.getGuidedCO2(), ind.getExplorerCO2(),
    				ind.getAccumulatedGuidedCO2(), ind.getAccumulatedExplorerCO2(),
    				controller.getSimulTime().toString()
    		);
    		return indicators;
		 }
		 catch(Exception e){
			 logger.error("Problems!!! Exception: " + e.getMessage());
			 return new ActivityIndicators();
	     }
	}
    
    @GET @Path("test")
    @Produces(MediaType.APPLICATION_JSON)
	public String test() {
    	return "{\"displayFieldName\":\"BuildingID\",\"fieldAliases\":{\"OBJECTID\":\"OBJECTID\",\"Z_Coordinate\":\"Z_Coordinate\",\"Floor\":\"Floor\",\"BuildingID\":\"BuildingID\",\"Type\":\"Type\"},\"geometryType\":\"esriGeometryPoint\",\"spatialReference\":{\"wkid\":102100,\"latestWkid\":3857},\"fields\":[{\"name\":\"OBJECTID\",\"type\":\"esriFieldTypeOID\",\"alias\":\"OBJECTID\"},{\"name\":\"Z_Coordinate\",\"type\":\"esriFieldTypeSmallInteger\",\"alias\":\"Z_Coordinate\"},{\"name\":\"Floor\",\"type\":\"esriFieldTypeSmallInteger\",\"alias\":\"Floor\"},{\"name\":\"BuildingID\",\"type\":\"esriFieldTypeString\",\"alias\":\"BuildingID\",\"length\":2},{\"name\":\"Type\",\"type\":\"esriFieldTypeSmallInteger\",\"alias\":\"Type\"}],\"features\":[{\"attributes\":{\"OBJECTID\":1,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7367.3555000014603,\"y\":4865127.8901999965}},{\"attributes\":{\"OBJECTID\":2,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7363.6222000010312,\"y\":4865162.1523000002}},{\"attributes\":{\"OBJECTID\":3,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7361.0824000015855,\"y\":4865160.6110000014}},{\"attributes\":{\"OBJECTID\":4,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JC\",\"Type\":1},\"geometry\":{\"x\":-7230.3071999996901,\"y\":4865091.8506999984}},{\"attributes\":{\"OBJECTID\":5,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JC\",\"Type\":1},\"geometry\":{\"x\":-7171.9074999988079,\"y\":4865057.1010000035}},{\"attributes\":{\"OBJECTID\":6,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JC\",\"Type\":1},\"geometry\":{\"x\":-7169.8722999989986,\"y\":4865060.4949999973}},{\"attributes\":{\"OBJECTID\":7,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JC\",\"Type\":1},\"geometry\":{\"x\":-7521.1754000000656,\"y\":4865244.7393999994}},{\"attributes\":{\"OBJECTID\":8,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JC\",\"Type\":1},\"geometry\":{\"x\":-7513.0559000000358,\"y\":4865259.7040999979}},{\"attributes\":{\"OBJECTID\":9,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JC\",\"Type\":1},\"geometry\":{\"x\":-7457.9221000000834,\"y\":4865219.1696000025}},{\"attributes\":{\"OBJECTID\":10,\"Z_Coordinate\":8,\"Floor\":1,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7636.1259000003338,\"y\":4865253.7031000033}},{\"attributes\":{\"OBJECTID\":11,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7590.3630000017583,\"y\":4865294.6762000024}},{\"attributes\":{\"OBJECTID\":12,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7647.8009999990463,\"y\":4865285.6828999966}},{\"attributes\":{\"OBJECTID\":13,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7879.6717999987304,\"y\":4865253.0595000014}},{\"attributes\":{\"OBJECTID\":14,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TC\",\"Type\":1},\"geometry\":{\"x\":-7328.1732000000775,\"y\":4864776.0297999978}},{\"attributes\":{\"OBJECTID\":15,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TI\",\"Type\":1},\"geometry\":{\"x\":-7644.8698999993503,\"y\":4864954.1517999992}},{\"attributes\":{\"OBJECTID\":16,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7480.0219999998808,\"y\":4864905.7094999999}},{\"attributes\":{\"OBJECTID\":17,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7519.4670999981463,\"y\":4864951.3772}},{\"attributes\":{\"OBJECTID\":18,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7418.0355999991298,\"y\":4864894.9448999986}},{\"attributes\":{\"OBJECTID\":19,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7420.4092999994755,\"y\":4864896.2963000014}},{\"attributes\":{\"OBJECTID\":20,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7459.9923000000417,\"y\":4864866.1164000034}},{\"attributes\":{\"OBJECTID\":21,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":0},\"geometry\":{\"x\":-8233.4255999997258,\"y\":4865067.8967000023}},{\"attributes\":{\"OBJECTID\":22,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":0},\"geometry\":{\"x\":-8252.0885999985039,\"y\":4865034.1833000034}},{\"attributes\":{\"OBJECTID\":23,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":0},\"geometry\":{\"x\":-8265.9899999983609,\"y\":4865064.9965000004}},{\"attributes\":{\"OBJECTID\":24,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7847.5573000013828,\"y\":4865308.4296000004}},{\"attributes\":{\"OBJECTID\":25,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7820.9063000008464,\"y\":4865293.7766000032}},{\"attributes\":{\"OBJECTID\":26,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7793.9675000011921,\"y\":4865278.5073999986}},{\"attributes\":{\"OBJECTID\":27,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7941.8465000018477,\"y\":4865266.9853999987}},{\"attributes\":{\"OBJECTID\":28,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7956.9325999990106,\"y\":4865299.4958999977}},{\"attributes\":{\"OBJECTID\":29,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7942.9704000018537,\"y\":4865324.6797000021}},{\"attributes\":{\"OBJECTID\":30,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7907.5361000001431,\"y\":4865328.9536999986}},{\"attributes\":{\"OBJECTID\":31,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7863.0089999996126,\"y\":4865283.2736999989}},{\"attributes\":{\"OBJECTID\":32,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7273.2549000009894,\"y\":4865116.3360000029}},{\"attributes\":{\"OBJECTID\":33,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":1},\"geometry\":{\"x\":-8208.7116999998689,\"y\":4865051.7730000019}},{\"attributes\":{\"OBJECTID\":34,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":1},\"geometry\":{\"x\":-8229.8282000012696,\"y\":4865024.6714999974}},{\"attributes\":{\"OBJECTID\":35,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UA\",\"Type\":0},\"geometry\":{\"x\":-8161.7807999998331,\"y\":4865019.1577999964}},{\"attributes\":{\"OBJECTID\":36,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UA\",\"Type\":0},\"geometry\":{\"x\":-8134.4508000016212,\"y\":4864988.4155000001}},{\"attributes\":{\"OBJECTID\":37,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"EE\",\"Type\":1},\"geometry\":{\"x\":-8187.3482000008225,\"y\":4864858.3299999982}},{\"attributes\":{\"OBJECTID\":38,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"EE\",\"Type\":1},\"geometry\":{\"x\":-8110.1317999996245,\"y\":4864884.0406000018}},{\"attributes\":{\"OBJECTID\":39,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"NB\",\"Type\":1},\"geometry\":{\"x\":-7980.748900000006,\"y\":4864900.2000999972}},{\"attributes\":{\"OBJECTID\":40,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"MI\",\"Type\":1},\"geometry\":{\"x\":-7848.2855000011623,\"y\":4864813.8751000017}},{\"attributes\":{\"OBJECTID\":41,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"MI\",\"Type\":1},\"geometry\":{\"x\":-7827.0711999982595,\"y\":4864852.064199999}},{\"attributes\":{\"OBJECTID\":42,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TT\",\"Type\":1},\"geometry\":{\"x\":-7725.7395999990404,\"y\":4864766.6306999996}},{\"attributes\":{\"OBJECTID\":43,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TT\",\"Type\":1},\"geometry\":{\"x\":-7717.5733999982476,\"y\":4864796.139200002}},{\"attributes\":{\"OBJECTID\":44,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TT\",\"Type\":1},\"geometry\":{\"x\":-7645.533900000155,\"y\":4864744.1964000016}},{\"attributes\":{\"OBJECTID\":45,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TT\",\"Type\":1},\"geometry\":{\"x\":-7660.5731999985874,\"y\":4864716.2842999995}},{\"attributes\":{\"OBJECTID\":46,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TT\",\"Type\":1},\"geometry\":{\"x\":-7611.1585000008345,\"y\":4864679.5090999976}},{\"attributes\":{\"OBJECTID\":47,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TT\",\"Type\":1},\"geometry\":{\"x\":-7567.2285000011325,\"y\":4864652.4180999994}},{\"attributes\":{\"OBJECTID\":48,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TT\",\"Type\":1},\"geometry\":{\"x\":-7563.5709000006318,\"y\":4864687.9866999984}},{\"attributes\":{\"OBJECTID\":49,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"NA\",\"Type\":1},\"geometry\":{\"x\":-7456.7674999982119,\"y\":4864645.1494999975}},{\"attributes\":{\"OBJECTID\":50,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"NA\",\"Type\":1},\"geometry\":{\"x\":-7474.0115999989212,\"y\":4864629.2964000031}},{\"attributes\":{\"OBJECTID\":51,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"NA\",\"Type\":1},\"geometry\":{\"x\":-7425.1669999994338,\"y\":4864601.8853999972}},{\"attributes\":{\"OBJECTID\":52,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"NA\",\"Type\":1},\"geometry\":{\"x\":-7419.3828999996185,\"y\":4864624.2551999986}},{\"attributes\":{\"OBJECTID\":53,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TC\",\"Type\":1},\"geometry\":{\"x\":-7383.0969000011683,\"y\":4864757.6111000031}},{\"attributes\":{\"OBJECTID\":54,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7470.3881999999285,\"y\":4864803.6731000021}},{\"attributes\":{\"OBJECTID\":55,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7505.3038000017405,\"y\":4864827.2960999981}},{\"attributes\":{\"OBJECTID\":56,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7521.0769999995828,\"y\":4864886.6928000003}},{\"attributes\":{\"OBJECTID\":57,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7572.2036999985576,\"y\":4864860.5860000029}},{\"attributes\":{\"OBJECTID\":58,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TI\",\"Type\":1},\"geometry\":{\"x\":-7630.0678000003099,\"y\":4864894.508100003}},{\"attributes\":{\"OBJECTID\":59,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TI\",\"Type\":1},\"geometry\":{\"x\":-7697.2553999982774,\"y\":4864931.7604999989}},{\"attributes\":{\"OBJECTID\":60,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"CD\",\"Type\":0},\"geometry\":{\"x\":-7783.4365000016987,\"y\":4864975.0367000028}},{\"attributes\":{\"OBJECTID\":61,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DB\",\"Type\":0},\"geometry\":{\"x\":-7911.3092000000179,\"y\":4865045.5816000029}},{\"attributes\":{\"OBJECTID\":62,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DB\",\"Type\":0},\"geometry\":{\"x\":-7931.8365000002086,\"y\":4865056.987999998}},{\"attributes\":{\"OBJECTID\":63,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DB\",\"Type\":0},\"geometry\":{\"x\":-7958.3262000009418,\"y\":4865071.5621000007}},{\"attributes\":{\"OBJECTID\":64,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DB\",\"Type\":0},\"geometry\":{\"x\":-7982.0089999996126,\"y\":4865085.7437999994}},{\"attributes\":{\"OBJECTID\":65,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DC\",\"Type\":0},\"geometry\":{\"x\":-8102.383299998939,\"y\":4865087.5869999975}},{\"attributes\":{\"OBJECTID\":66,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DC\",\"Type\":0},\"geometry\":{\"x\":-8072.9083000011742,\"y\":4865069.816200003}},{\"attributes\":{\"OBJECTID\":67,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DB\",\"Type\":0},\"geometry\":{\"x\":-7973.8227000012994,\"y\":4865136.233099997}},{\"attributes\":{\"OBJECTID\":68,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DB\",\"Type\":1},\"geometry\":{\"x\":-7867.826099999249,\"y\":4865110.5178000033}},{\"attributes\":{\"OBJECTID\":69,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7866.1798000000417,\"y\":4865211.8291999996}},{\"attributes\":{\"OBJECTID\":70,\"Z_Coordinate\":8,\"Floor\":1,\"BuildingID\":\"CD\",\"Type\":1},\"geometry\":{\"x\":-7728.9690000005066,\"y\":4865075.2718999982}},{\"attributes\":{\"OBJECTID\":71,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TC\",\"Type\":1},\"geometry\":{\"x\":-7321.9897999987006,\"y\":4864787.7971000001}},{\"attributes\":{\"OBJECTID\":72,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TC\",\"Type\":1},\"geometry\":{\"x\":-7337.1832999996841,\"y\":4864840.3233999982}},{\"attributes\":{\"OBJECTID\":73,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TC\",\"Type\":1},\"geometry\":{\"x\":-7405.1735000014305,\"y\":4864826.2669999972}},{\"attributes\":{\"OBJECTID\":74,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7427.2809000015259,\"y\":4864844.9531000033}},{\"attributes\":{\"OBJECTID\":75,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7572.5714999996126,\"y\":4864913.1851999983}},{\"attributes\":{\"OBJECTID\":76,\"Z_Coordinate\":8,\"Floor\":1,\"BuildingID\":\"TI\",\"Type\":1},\"geometry\":{\"x\":-7626.1787000000477,\"y\":4864956.2404000014}},{\"attributes\":{\"OBJECTID\":77,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TI\",\"Type\":1},\"geometry\":{\"x\":-7639.6490999981761,\"y\":4864963.3167999983}},{\"attributes\":{\"OBJECTID\":78,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TI\",\"Type\":1},\"geometry\":{\"x\":-7648.5656999982893,\"y\":4865019.6438999996}},{\"attributes\":{\"OBJECTID\":79,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TI\",\"Type\":1},\"geometry\":{\"x\":-7581.1088999994099,\"y\":4864982.2580000013}},{\"attributes\":{\"OBJECTID\":80,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"CD\",\"Type\":0},\"geometry\":{\"x\":-7750.9684000015259,\"y\":4865029.1542000026}},{\"attributes\":{\"OBJECTID\":81,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"CD\",\"Type\":1},\"geometry\":{\"x\":-7755.6337999999523,\"y\":4865019.4127999991}},{\"attributes\":{\"OBJECTID\":82,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"CD\",\"Type\":0},\"geometry\":{\"x\":-7710.1000000014901,\"y\":4865054.8694999963}},{\"attributes\":{\"OBJECTID\":83,\"Z_Coordinate\":8,\"Floor\":1,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7623.7523000016809,\"y\":4865246.6410999969}},{\"attributes\":{\"OBJECTID\":84,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7811.2164999991655,\"y\":4865233.1701000035}},{\"attributes\":{\"OBJECTID\":85,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7839.486099999398,\"y\":4865196.9350000024}},{\"attributes\":{\"OBJECTID\":86,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7892.7723000012338,\"y\":4865226.6209999993}},{\"attributes\":{\"OBJECTID\":87,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7907.3563000001013,\"y\":4865266.2599000037}},{\"attributes\":{\"OBJECTID\":88,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7888.8623999990523,\"y\":4865299.8408000022}},{\"attributes\":{\"OBJECTID\":89,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DA\",\"Type\":1},\"geometry\":{\"x\":-7776.992800001055,\"y\":4865355.5261999965}},{\"attributes\":{\"OBJECTID\":90,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7569.7254000008106,\"y\":4865358.3101999983}},{\"attributes\":{\"OBJECTID\":91,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":0},\"geometry\":{\"x\":-7534.9442999996245,\"y\":4865340.6498999968}},{\"attributes\":{\"OBJECTID\":92,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"FF\",\"Type\":1},\"geometry\":{\"x\":-7383.3383000008762,\"y\":4865384.2050999999}},{\"attributes\":{\"OBJECTID\":93,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"FF\",\"Type\":1},\"geometry\":{\"x\":-7358.0458999983966,\"y\":4865418.2356000021}},{\"attributes\":{\"OBJECTID\":94,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"IT\",\"Type\":1},\"geometry\":{\"x\":-7290.8700999990106,\"y\":4865372.8025999963}},{\"attributes\":{\"OBJECTID\":95,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"IT\",\"Type\":1},\"geometry\":{\"x\":-7273.209699999541,\"y\":4865362.5861999989}},{\"attributes\":{\"OBJECTID\":96,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"IT\",\"Type\":1},\"geometry\":{\"x\":-7255.103100001812,\"y\":4865361.2163000032}},{\"attributes\":{\"OBJECTID\":97,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"IT\",\"Type\":1},\"geometry\":{\"x\":-7194.1501000002027,\"y\":4865331.2446999997}},{\"attributes\":{\"OBJECTID\":98,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"AC\",\"Type\":1},\"geometry\":{\"x\":-7083.5087999999523,\"y\":4865274.314199999}},{\"attributes\":{\"OBJECTID\":99,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"AC\",\"Type\":1},\"geometry\":{\"x\":-7096.0284999981523,\"y\":4865254.3597000018}},{\"attributes\":{\"OBJECTID\":100,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"IT\",\"Type\":1},\"geometry\":{\"x\":-7212.9981000013649,\"y\":4865292.4189999998}},{\"attributes\":{\"OBJECTID\":101,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"IT\",\"Type\":1},\"geometry\":{\"x\":-7205.265000000596,\"y\":4865320.5762000009}},{\"attributes\":{\"OBJECTID\":102,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"IT\",\"Type\":1},\"geometry\":{\"x\":-7212.082800000906,\"y\":4865307.9113000035}},{\"attributes\":{\"OBJECTID\":103,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"IT\",\"Type\":1},\"geometry\":{\"x\":-7263.4585000015795,\"y\":4865318.0697000027}},{\"attributes\":{\"OBJECTID\":104,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7408.8751000016928,\"y\":4865191.5733999982}},{\"attributes\":{\"OBJECTID\":105,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JC\",\"Type\":1},\"geometry\":{\"x\":-7508.2582000009716,\"y\":4865283.8941000029}},{\"attributes\":{\"OBJECTID\":106,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JC\",\"Type\":1},\"geometry\":{\"x\":-7539.743299998343,\"y\":4865227.8959999979}},{\"attributes\":{\"OBJECTID\":107,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7617.410300001502,\"y\":4865246.1203000024}},{\"attributes\":{\"OBJECTID\":108,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7640.3247999995947,\"y\":4865258.8809999973}},{\"attributes\":{\"OBJECTID\":109,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7613.1724000014365,\"y\":4865307.1369000003}},{\"attributes\":{\"OBJECTID\":110,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":0},\"geometry\":{\"x\":-7631.4186000004411,\"y\":4865348.8650999963}},{\"attributes\":{\"OBJECTID\":111,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HD\",\"Type\":1},\"geometry\":{\"x\":-8015.6074000000954,\"y\":4865383.2261999995}},{\"attributes\":{\"OBJECTID\":112,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HD\",\"Type\":1},\"geometry\":{\"x\":-8008.8359999991953,\"y\":4865250.5345999971}},{\"attributes\":{\"OBJECTID\":113,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HD\",\"Type\":1},\"geometry\":{\"x\":-8013.9902999997139,\"y\":4865349.0077999979}},{\"attributes\":{\"OBJECTID\":114,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HD\",\"Type\":1},\"geometry\":{\"x\":-8011.0326000005007,\"y\":4865291.9167999998}},{\"attributes\":{\"OBJECTID\":115,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HD\",\"Type\":1},\"geometry\":{\"x\":-8011.9501000009477,\"y\":4865311.2276000008}},{\"attributes\":{\"OBJECTID\":116,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HD\",\"Type\":1},\"geometry\":{\"x\":-8009.3564999997616,\"y\":4865195.442400001}},{\"attributes\":{\"OBJECTID\":117,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DC\",\"Type\":1},\"geometry\":{\"x\":-8044.3583000004292,\"y\":4865134.8132999986}},{\"attributes\":{\"OBJECTID\":118,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"DC\",\"Type\":0},\"geometry\":{\"x\":-8087.2201000005007,\"y\":4865148.3439000025}},{\"attributes\":{\"OBJECTID\":119,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"CD\",\"Type\":0},\"geometry\":{\"x\":-7762.1856000013649,\"y\":4865035.3540000021}},{\"attributes\":{\"OBJECTID\":120,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"CD\",\"Type\":0},\"geometry\":{\"x\":-7766.6834999993443,\"y\":4865026.8872999996}},{\"attributes\":{\"OBJECTID\":121,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7318.6768999993801,\"y\":4865183.0578999966}},{\"attributes\":{\"OBJECTID\":122,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7811.0901999995112,\"y\":4865158.3716000021}},{\"attributes\":{\"OBJECTID\":123,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7795.506099998951,\"y\":4865186.5762000009}},{\"attributes\":{\"OBJECTID\":124,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7793.8922000005841,\"y\":4865193.4024000019}},{\"attributes\":{\"OBJECTID\":125,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7767.3280000016093,\"y\":4865241.1121999994}},{\"attributes\":{\"OBJECTID\":126,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7754.3581000007689,\"y\":4865243.6944999993}},{\"attributes\":{\"OBJECTID\":127,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7740.6975999996066,\"y\":4865265.0781999975}},{\"attributes\":{\"OBJECTID\":128,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7686.4976000003517,\"y\":4865245.4725999981}},{\"attributes\":{\"OBJECTID\":129,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7693.4825999997556,\"y\":4865244.7053000033}},{\"attributes\":{\"OBJECTID\":130,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7700.3618000000715,\"y\":4865243.3294999972}},{\"attributes\":{\"OBJECTID\":131,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7707.0822999998927,\"y\":4865241.318599999}},{\"attributes\":{\"OBJECTID\":132,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7713.6572000011802,\"y\":4865238.7388999984}},{\"attributes\":{\"OBJECTID\":133,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7719.9541999995708,\"y\":4865235.6828000024}},{\"attributes\":{\"OBJECTID\":134,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7726.4101000018418,\"y\":4865231.8068000004}},{\"attributes\":{\"OBJECTID\":135,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7732.0722000002861,\"y\":4865227.7057000026}},{\"attributes\":{\"OBJECTID\":136,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7737.4563999995589,\"y\":4865223.1548999995}},{\"attributes\":{\"OBJECTID\":137,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7742.3115999996662,\"y\":4865218.0483999997}},{\"attributes\":{\"OBJECTID\":138,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7690.1290999986231,\"y\":4865264.5821999982}},{\"attributes\":{\"OBJECTID\":139,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7694.5144000016153,\"y\":4865264.1521999985}},{\"attributes\":{\"OBJECTID\":140,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7707.1550000011921,\"y\":4865261.4997000024}},{\"attributes\":{\"OBJECTID\":141,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7711.2626999989152,\"y\":4865260.2959000021}},{\"attributes\":{\"OBJECTID\":142,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7723.3343000002205,\"y\":4865255.6722000018}},{\"attributes\":{\"OBJECTID\":143,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7727.3823999986053,\"y\":4865253.6679999977}},{\"attributes\":{\"OBJECTID\":144,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7738.9250000007451,\"y\":4865246.7294000015}},{\"attributes\":{\"OBJECTID\":145,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7742.4571000002325,\"y\":4865244.1692999974}},{\"attributes\":{\"OBJECTID\":146,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7749.0122000016272,\"y\":4865238.6860999987}},{\"attributes\":{\"OBJECTID\":147,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7754.654399998486,\"y\":4865122.7057000026}},{\"attributes\":{\"OBJECTID\":148,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7757.6242999993265,\"y\":4865129.0688000023}},{\"attributes\":{\"OBJECTID\":149,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7761.9107000008225,\"y\":4865142.4170999974}},{\"attributes\":{\"OBJECTID\":150,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7763.2467000000179,\"y\":4865149.316200003}},{\"attributes\":{\"OBJECTID\":151,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7763.9611999988556,\"y\":4865156.3408000022}},{\"attributes\":{\"OBJECTID\":152,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7764.0841999985278,\"y\":4865163.8643999994}},{\"attributes\":{\"OBJECTID\":153,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7763.5973999984562,\"y\":4865170.8308999985}},{\"attributes\":{\"OBJECTID\":154,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7762.5494999997318,\"y\":4865177.7946999967}},{\"attributes\":{\"OBJECTID\":155,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7760.0452000014484,\"y\":4865135.6569999978}},{\"attributes\":{\"OBJECTID\":156,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":1},\"geometry\":{\"x\":-7760.8953999988735,\"y\":4865184.6216000021}},{\"attributes\":{\"OBJECTID\":157,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7781.9065999984741,\"y\":4865179.2736999989}},{\"attributes\":{\"OBJECTID\":158,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7783.0441999994218,\"y\":4865170.8466999978}},{\"attributes\":{\"OBJECTID\":159,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7783.3883000016212,\"y\":4865166.3355000019}},{\"attributes\":{\"OBJECTID\":160,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7783.0707000009716,\"y\":4865152.9477000013}},{\"attributes\":{\"OBJECTID\":161,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7782.6605999991298,\"y\":4865148.5552999973}},{\"attributes\":{\"OBJECTID\":162,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7780.2661000005901,\"y\":4865135.9479999989}},{\"attributes\":{\"OBJECTID\":163,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7778.9829999990761,\"y\":4865131.820600003}},{\"attributes\":{\"OBJECTID\":164,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7774.6438000015914,\"y\":4865119.6099999994}},{\"attributes\":{\"OBJECTID\":165,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7772.7122999988496,\"y\":4865115.5617000014}},{\"attributes\":{\"OBJECTID\":166,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":0},\"geometry\":{\"x\":-8234.9728999994695,\"y\":4865068.6731000021}},{\"attributes\":{\"OBJECTID\":167,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":0},\"geometry\":{\"x\":-8253.758299998939,\"y\":4865035.0709000006}},{\"attributes\":{\"OBJECTID\":168,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":0},\"geometry\":{\"x\":-8223.0665999986231,\"y\":4865024.0907000005}},{\"attributes\":{\"OBJECTID\":169,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":0},\"geometry\":{\"x\":-8215.1290999986231,\"y\":4865051.2106000036}},{\"attributes\":{\"OBJECTID\":170,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":0},\"geometry\":{\"x\":-8184.0403999984264,\"y\":4865022.2386000007}},{\"attributes\":{\"OBJECTID\":171,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UB\",\"Type\":0},\"geometry\":{\"x\":-8187.3476999998093,\"y\":4865016.4178000018}},{\"attributes\":{\"OBJECTID\":172,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UA\",\"Type\":0},\"geometry\":{\"x\":-8168.429999999702,\"y\":4865007.686499998}},{\"attributes\":{\"OBJECTID\":173,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"UA\",\"Type\":1},\"geometry\":{\"x\":-8129.6684999987483,\"y\":4864996.3093999997}},{\"attributes\":{\"OBJECTID\":174,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"NB\",\"Type\":1},\"geometry\":{\"x\":-7979.4338999986649,\"y\":4864939.3671000004}},{\"attributes\":{\"OBJECTID\":175,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"NB\",\"Type\":1},\"geometry\":{\"x\":-7974.8830000013113,\"y\":4864897.3511999995}},{\"attributes\":{\"OBJECTID\":176,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7432.3671000003815,\"y\":4864835.7952999994}},{\"attributes\":{\"OBJECTID\":177,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7492.8376999981701,\"y\":4864825.5691}},{\"attributes\":{\"OBJECTID\":178,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7518.8728000000119,\"y\":4864835.0942000002}},{\"attributes\":{\"OBJECTID\":179,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7463.5879000015557,\"y\":4864868.074500002}},{\"attributes\":{\"OBJECTID\":180,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7474.4226999990642,\"y\":4864874.1467000023}},{\"attributes\":{\"OBJECTID\":181,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7477.8755000010133,\"y\":4864876.0517000034}},{\"attributes\":{\"OBJECTID\":182,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7481.8839000016451,\"y\":4864857.3589000031}},{\"attributes\":{\"OBJECTID\":183,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7483.5905000008643,\"y\":4864858.3113999963}},{\"attributes\":{\"OBJECTID\":184,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7513.4884000010788,\"y\":4864877.0108999982}},{\"attributes\":{\"OBJECTID\":185,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7506.3315000012517,\"y\":4864891.7679999992}},{\"attributes\":{\"OBJECTID\":186,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7509.6651999987662,\"y\":4864893.6730000004}},{\"attributes\":{\"OBJECTID\":187,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7520.6587000004947,\"y\":4864899.7783000022}},{\"attributes\":{\"OBJECTID\":188,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7523.9990999996662,\"y\":4864901.6436000019}},{\"attributes\":{\"OBJECTID\":189,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7567.2903999984264,\"y\":4864922.7308000028}},{\"attributes\":{\"OBJECTID\":190,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TD\",\"Type\":1},\"geometry\":{\"x\":-7521.8867000006139,\"y\":4864952.6890999973}},{\"attributes\":{\"OBJECTID\":191,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"TC\",\"Type\":1},\"geometry\":{\"x\":-7410.9039000011981,\"y\":4864773.7713000029}},{\"attributes\":{\"OBJECTID\":192,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7841.7195000015199,\"y\":4865193.5917999968}},{\"attributes\":{\"OBJECTID\":193,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7868.3896000012755,\"y\":4865208.196800001}},{\"attributes\":{\"OBJECTID\":194,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7894.7421000003815,\"y\":4865223.4368999973}},{\"attributes\":{\"OBJECTID\":195,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7792.0306999981403,\"y\":4865282.1745000035}},{\"attributes\":{\"OBJECTID\":196,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7819.0181999988854,\"y\":4865297.2558000013}},{\"attributes\":{\"OBJECTID\":197,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7845.8469999991357,\"y\":4865312.1783000007}},{\"attributes\":{\"OBJECTID\":198,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7806.6620999984443,\"y\":4865251.8796000034}},{\"attributes\":{\"OBJECTID\":199,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"HC\",\"Type\":1},\"geometry\":{\"x\":-7823.4631999991834,\"y\":4865221.4525000006}},{\"attributes\":{\"OBJECTID\":200,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7800.9780000001192,\"y\":4865156.3008999974}},{\"attributes\":{\"OBJECTID\":201,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7797.8823999986053,\"y\":4865161.936499998}},{\"attributes\":{\"OBJECTID\":202,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7794.7074000015855,\"y\":4865167.7308999971}},{\"attributes\":{\"OBJECTID\":203,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7791.6116999983788,\"y\":4865173.3665999994}},{\"attributes\":{\"OBJECTID\":204,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7788.2780000008643,\"y\":4865179.0022}},{\"attributes\":{\"OBJECTID\":205,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7751.1369000002742,\"y\":4865112.3118000031}},{\"attributes\":{\"OBJECTID\":206,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7756.5344000011683,\"y\":4865111.5578000024}},{\"attributes\":{\"OBJECTID\":207,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7759.2727999985218,\"y\":4865106.7158999965}},{\"attributes\":{\"OBJECTID\":208,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7595.5533999986947,\"y\":4865307.0882999972}},{\"attributes\":{\"OBJECTID\":209,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"RR\",\"Type\":1},\"geometry\":{\"x\":-7600.395300000906,\"y\":4865309.310800001}},{\"attributes\":{\"OBJECTID\":210,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7327.1688000001013,\"y\":4865141.6537000015}},{\"attributes\":{\"OBJECTID\":211,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7324.4567999988794,\"y\":4865140.1322999969}},{\"attributes\":{\"OBJECTID\":212,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7362.9538000002503,\"y\":4865122.4051999971}},{\"attributes\":{\"OBJECTID\":213,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7358.7204000018537,\"y\":4865119.9578000009}},{\"attributes\":{\"OBJECTID\":214,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7351.5104999989271,\"y\":4865119.1640999988}},{\"attributes\":{\"OBJECTID\":215,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7321.4803000018001,\"y\":4865184.4500999972}},{\"attributes\":{\"OBJECTID\":216,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7327.8302999995649,\"y\":4865188.0219999999}},{\"attributes\":{\"OBJECTID\":217,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7330.4761000014842,\"y\":4865189.4111000001}},{\"attributes\":{\"OBJECTID\":218,\"Z_Coordinate\":0,\"Floor\":-1,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7348.991700001061,\"y\":4865196.6394999996}},{\"attributes\":{\"OBJECTID\":219,\"Z_Coordinate\":0,\"Floor\":-1,\"BuildingID\":\"JA\",\"Type\":1},\"geometry\":{\"x\":-7363.702500000596,\"y\":4865207.5932999998}},{\"attributes\":{\"OBJECTID\":220,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7676.4283000007272,\"y\":4865255.4230000004}},{\"attributes\":{\"OBJECTID\":221,\"Z_Coordinate\":4,\"Floor\":0,\"BuildingID\":\"GG\",\"Type\":0},\"geometry\":{\"x\":-7676.7589999996126,\"y\":4865250.4620999992}},{\"attributes\":{\"OBJECTID\":222,\"Z_Coordinate\":8,\"Floor\":1,\"BuildingID\":\"TI\",\"Type\":1},\"geometry\":{\"x\":-7631.5604000017047,\"y\":4864946.4455000013}},{\"attributes\":{\"OBJECTID\":223,\"Z_Coordinate\":8,\"Floor\":1,\"BuildingID\":\"CD\",\"Type\":0},\"geometry\":{\"x\":-7725.8931999988854,\"y\":4865073.5521000028}},{\"attributes\":{\"OBJECTID\":224,\"Z_Coordinate\":8,\"Floor\":1,\"BuildingID\":\"CD\",\"Type\":0},\"geometry\":{\"x\":-7722.8836000002921,\"y\":4865071.8322999999}},{\"attributes\":{\"OBJECTID\":225,\"Z_Coordinate\":8,\"Floor\":1,\"BuildingID\":\"CD\",\"Type\":0},\"geometry\":{\"x\":-7719.6755000017583,\"y\":4865070.1455999985}}]}";
	}
}
